@@ -1,7 +1,7 @@
 use crate::actions::Action;
 use crate::config::{RuleConfig, VariableInfo};
 use crate::rules::RulesContext;
-use crate::template_engine::Context;
+use crate::vendor::tera::Context;
 use crate::{Archetect, ArchetectError, Archetype};
 use linked_hash_map::LinkedHashMap;
 use std::path::Path;
@@ -22,7 +22,7 @@ pub struct DestinationOptions {
 impl Action for RuleType {
     fn execute<D: AsRef<Path>>(
         &self,
-        _archetect: &Archetect,
+        _archetect: &mut Archetect,
         _archetype: &Archetype,
         _destination: D,
         rules_context: &mut RulesContext,
