@@ -21,6 +21,7 @@ pub struct Archetect {
     tera: Tera,
     paths: Rc<Box<dyn SystemLayout>>,
     offline: bool,
+    headless: bool,
     switches: HashSet<String>,
 }
 
@@ -33,6 +34,10 @@ impl Archetect {
         self.offline
     }
 
+    pub fn headless(&self) -> bool {
+        self.headless
+    }
+
     pub fn builder() -> ArchetectBuilder {
         ArchetectBuilder::new()
     }
@@ -193,6 +198,7 @@ impl Archetect {
 pub struct ArchetectBuilder {
     layout: Option<Box<dyn SystemLayout>>,
     offline: bool,
+    headless: bool,
     switches: HashSet<String>,
 }
 
@@ -201,6 +207,7 @@ impl ArchetectBuilder {
         ArchetectBuilder {
             layout: None,
             offline: false,
+            headless: false,
             switches: HashSet::new(),
         }
     }
@@ -214,6 +221,7 @@ impl ArchetectBuilder {
             tera: crate::vendor::tera::extensions::create_tera(),
             paths,
             offline: self.offline,
+            headless: self.headless,
             switches: self.switches,
         })
     }
@@ -236,6 +244,11 @@ impl ArchetectBuilder {
         self.offline = offline;
         self
     }
+
+    pub fn with_headless(mut self, headless: bool) -> ArchetectBuilder {
+        self.headless = headless;
+        self
+    }
 }
 
 #[cfg(test)]
